import java.awt.BorderLayout;
import java.awt.Button;
import java.awt.Dialog;
import java.awt.FlowLayout;
import java.awt.Font;
import java.awt.Frame;
import java.awt.Dimension;
import java.awt.GridLayout;
import java.awt.Label;
import java.awt.Panel;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

/**
   Defines a simple frame with one button that creates a
   dialog in a separate frame.  The dialog created by this
   example must have an associated frame.  An instance of
   this class provides that frame.

   <p> We don't need to specify a getPreferredSize() method
   because we are adding a button to the frame.  The size
   required by the button will be the minumum size allocated
   for the frame.
*/
public class DialogExample extends Frame implements ActionListener
{
  /**
     Constructor. Creates an instance of a frame with a
     button. Pressing the button brings up a dialog.  

     @param title the title of the frame, not the dialog.
  */
  public DialogExample(String title)
  {
    super(title);

    Font f18 = new Font("SansSerif", Font.PLAIN, 18);
    Font f14 = new Font("SansSerif", Font.PLAIN, 14);

    Button b = new Button("Bring up dialog");
    b.setFont(f18);
    b.addActionListener(this);

    // Create a nested container and add the button to it.
    //
    Panel p = new Panel();
    p.add(b);

    add(p);
  }

  /**
     Creates the dialog and launches it (makes it visible).
  */
  public void actionPerformed(ActionEvent e)
  {
    // Notice that "this", the application, which is a
    // frame, is passed as the first argument.
    //
    d = new CustomDialog(this, "Make a decision", true);
    d.setVisible(true);
  }

  public static void main(String [] args)
  {
    DialogExample app = new DialogExample("Dialog Example");

    app.pack();
    app.setVisible(true);
  }

  Dialog d; 
}


/**
   A separate class that defines the dialog box created by
   the application.  Dialog boxes are frames.  They exist in
   a separate frame from the application that launches them.
   But they must still be associated with a frame.  
*/
class CustomDialog extends Dialog
{
  /**
     Constructor.  Builds a dialog box.  A reference to a
     frame is required to create a dialog.

     @param parent the associated parent frame of this dialog.

     @param title this dialog's title.

     @param modal the behavior of the
     dialog. <code>true</code> means modal, otherwise it's
     non-modal.
  */
  CustomDialog(Frame parent, String title, boolean modal)
  {
    super(parent, title, modal);

    Panel p1 = new Panel(new FlowLayout(FlowLayout.LEFT));
    Label question = new Label("And now what?");
    question.setFont(new Font("SansSerif", Font.PLAIN, 18));
    p1.add(question);

    add(p1, BorderLayout.CENTER);

    Panel p2 = new Panel(new FlowLayout(FlowLayout.RIGHT));

    dontknow = new Button("Don't know");
    dontknow.setFont(new Font("SansSerif", Font.PLAIN, 18));
    cancel = new Button("Cancel");
    cancel.setFont(new Font("SansSerif", Font.PLAIN, 18));

    p2.add(dontknow);
    p2.add(cancel);

    add(p2, BorderLayout.SOUTH);
    pack();
  }


  Button dontknow;
  Button cancel;
}
