import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.border.*;

/**
   This class demonstrates use of Swing labels.  The program paints a
   black border around each label to demonstrate label alignment.
   
   <p>You must distinguish between the area taken by a label's text
   and the are occupied by the whole label component.  The black
   borders outline the component area.  This enables you to see the
   alignment of the label's text within its display area.  
*/
public class Labels extends JPanel
{
  /**
     No-arg constructor.
  */
  public Labels()
  {
    setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));

    // No alignment specified.  The default is 0.0.
    //
    JLabel label4 = new JLabel("No alignment specified");
    label4.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(10, 10, 10, 10)));

    // Create a label.
    //
    JLabel zero = new JLabel("Horizontal Label alignment is 0.0");

    // Set the alignment to 0.0.
    //
    zero.setAlignmentX(0f);

    // Place a border around the label.
    //
    zero.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    // Repeat the above steps for all labels, increasing the shift
    // in alignment by 10%.  Each subsequent label will have 10%
    // more of its width aligned to the left of the CENTER of its
    // display area.
    //
    JLabel point1 = new JLabel("Horizontal Label alignment is 0.1");
    point1.setAlignmentX(0.1f);
    point1.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point2 = new JLabel("Horizontal Label alignment is 0.2");
    point2.setAlignmentX(0.2f);
    point2.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point3 = new JLabel("Horizontal Label alignment is 0.3");
    point3.setAlignmentX(0.3f);
    point3.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point4 = new JLabel("Horizontal Label alignment is 0.4");
    point4.setAlignmentX(0.4f);
    point4.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point5 = new JLabel("Horizontal Label alignment is 0.5");
    point5.setAlignmentX(0.5f);
    point5.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point6 = new JLabel("Horizontal Label alignment is 0.6");
    point6.setAlignmentX(0.6f);
    point6.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point7 = new JLabel("Horizontal Label alignment is 0.7");
    point7.setAlignmentX(0.7f);
    point7.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point8 = new JLabel("Horizontal Label alignment is 0.8");
    point8.setAlignmentX(0.8f);
    point8.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel point9 = new JLabel("Horizontal Label alignment is 0.9");
    point9.setAlignmentX(0.9f);
    point9.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    JLabel one = new JLabel("Horizontal Label alignment is 1.0");
    one.setAlignmentX(1f);
    one.setBorder(BorderFactory.createCompoundBorder(
		       BorderFactory.createLineBorder(Color.black, 2),
		       BorderFactory.createEmptyBorder(3, 3, 3, 3)));

    // Layout management stuff to make it display properly.
    //
    Box box = Box.createVerticalBox();

    Dimension dim = new Dimension(0, 10);

    box.add(label4);
    box.add(Box.createRigidArea(dim));

    box.add(zero);
    box.add(Box.createRigidArea(dim));

    box.add(point1);
    box.add(Box.createRigidArea(dim));

    box.add(point2);
    box.add(Box.createRigidArea(dim));

    box.add(point3);
    box.add(Box.createRigidArea(dim));

    box.add(point4);
    box.add(Box.createRigidArea(dim));

    box.add(point5);
    box.add(Box.createRigidArea(dim));

    box.add(point6);
    box.add(Box.createRigidArea(dim));

    box.add(point7);
    box.add(Box.createRigidArea(dim));

    box.add(point8);
    box.add(Box.createRigidArea(dim));

    box.add(point9);
    box.add(Box.createRigidArea(dim));

    box.add(one);

    add(box);
  }

  public static void main(String [] args)
  {
    Labels app = new Labels();

    JFrame f = new JFrame("JLabels Demo");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }

}
