import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
   This class demonstrates use of Swing radio buttons. Radio buttons
   by convention are used where only one radio button out of a set
   should be selected.  The JRadioButton class doesn't enforce this
   policy however.
*/
public class RadioButtons extends JPanel
{
  /**
     No-arg constructor.
  */
  public RadioButtons()
  {
    // Construct some radio buttons with mnemonic keys.  These first
    // four buttons do not enforce mutual selection exclusion.
    // 
    JRadioButton rb1 = new JRadioButton("Carbohydrate");
    rb1.setMnemonic('C');

    JRadioButton rb2 = new JRadioButton("Fat");
    rb2.setMnemonic('F');
    rb2.setRolloverEnabled(true);

    JRadioButton rb3 = new JRadioButton("Protein");
    rb3.setMnemonic('P');
    rb3.setFocusPainted(true);

    JRadioButton rb4 = new JRadioButton("Starch");
    rb4.setVerticalTextPosition(AbstractButton.TOP);
    rb4.setMnemonic('S');

    // Create a panel to hold this first group of radio buttons.  This
    // column appears to the left of the GUI.
    //
    JPanel chem = new JPanel();
    chem.setLayout(new GridLayout(0, 1));
    chem.add(rb1);
    chem.add(rb2);
    chem.add(rb3);
    chem.add(rb4);

    // Create a second set of radio buttons.  
    //
    JRadioButton rb5 = new JRadioButton("Dairy");
    rb5.setMnemonic('D');

    JRadioButton rb6 = new JRadioButton("Poultry");
    rb6.setMnemonic('l');

    JRadioButton rb7 = new JRadioButton("Meat");
    rb7.setMnemonic('M');

    JRadioButton rb8 = new JRadioButton("Vegetables");
    rb8.setMnemonic('V');

    // Create a button group, which does enforce mutual exclusion
    // of selection.
    ButtonGroup bg = new ButtonGroup();

    // Place the second set of buttons in this button group.
    //
    bg.add(rb5);
    bg.add(rb6);
    bg.add(rb7);
    bg.add(rb8);

    // Create the panel to hold the second group of buttons.  This
    // panel appears as the right-hand column of buttons on the GUI.
    //
    JPanel foodGroups = new JPanel();
    foodGroups.setLayout(new GridLayout(0, 1));
    foodGroups.add(rb5);
    foodGroups.add(rb6);
    foodGroups.add(rb7);
    foodGroups.add(rb8);

    add(chem);
    add(foodGroups);
  }

  public static void main(String [] args)
  {
    RadioButtons app = new RadioButtons();

    JFrame f = new JFrame("JRadioButton Demo");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }

}
