import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
   This class demonstrates use of the Swing tabbed pane component. It
   creates a JTabbedPane component with five tabs and a simple label
   in each tab's container.
*/
class TabbedPaneDemo extends JPanel
{
  /**
     No-arg constructor.
  */
  public TabbedPaneDemo()
  {
    Box box = Box.createVerticalBox();

    Dimension dim = new Dimension(500, 50);

    // Create the JPanel container to associate with tab 1 of the
    // tabbed pane. Also create a JLabel to place in the tab's
    // container (the JPanel).
    //
    JPanel panel1 = new JPanel();
    JLabel label1 = new JLabel("Looking at Panel 1.");
    panel1.add(label1);

    // Do the same for thing to create four more containers and labels
    // to associate with the other four tabs of the tabbed pane.
    //
    JPanel panel2 = new JPanel();
    JLabel label2 = new JLabel("Looking at Panel 2.");
    panel2.add(label2);

    JPanel panel3 = new JPanel();
    JLabel label3 = new JLabel("Looking at Panel 3.");
    panel3.add(label3);

    JPanel panel4 = new JPanel();
    JLabel label4 = new JLabel("Looking at Panel 4.");
    panel4.add(label4);

    JPanel panel5 = new JPanel();
    JLabel label5 = new JLabel("Looking at Panel 5.");
    panel5.add(label5);

    // Create the tabbed pane component and specify its preferred
    // size just for completeness.
    //
    JTabbedPane tabbedPane1 = new JTabbedPane();
    tabbedPane1.setPreferredSize(new Dimension(400, 200));

    // Add the five containers (the JPanels) to the tabbed pane.  Each
    // container is added as a component to its respective tab.  Also
    // specify the labels to appear in the tabs.
    //
    tabbedPane1.add("Panel 1", panel1);
    tabbedPane1.add("Panel 2", panel2);
    tabbedPane1.add("Panel 3", panel3);
    tabbedPane1.add("Panel 4", panel4);
    tabbedPane1.add("Panel 5", panel5);

    box.add(tabbedPane1);

    add(box);
  }


  public static void main(String [] args)
  {
    TabbedPaneDemo app = new TabbedPaneDemo();

    JFrame f = new JFrame("Tabbed Pane Demo");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }
}
