import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

/**
   This class demonstrates the use of Swing text fields.  It creates
   three text fields to demonstrate left-aligning, center-aligned, and
   right-aligned text, respectively.
*/
class TextFieldDemo extends JPanel
{
  /**
     No-arg constructor.
  */
  public TextFieldDemo()
  {
    Box box = Box.createVerticalBox();

    Font f14 = new Font("SansSerif", Font.PLAIN, 14);
    Dimension dim = new Dimension(300, 30);

    // Create a text field.  By default, the text is aligned to the
    // left.
    //
    JTextField text1 = new JTextField("This is left-aligned text.");
    text1.setFont(f14);
    text1.setPreferredSize(dim);
    text1.setScrollOffset(10);

    // Create a text field whose text is right-aligned.
    // 
    JTextField text2 = new JTextField("");
    text2.setFont(f14);
    text2.setText("This is right-aligned text.");
    text2.setHorizontalAlignment(JTextField.RIGHT);
    text2.setPreferredSize(dim);

    // Create a text field whose text is center-aligned.  The text is
    // highlighted when the user drags the mouse in the text field.
    //
    JTextField text3 = new 
      JTextField("This is center-aligned, highlighted text.");
    text3.setFont(f14);
    text3.setHorizontalAlignment(JTextField.CENTER);
    text3.setPreferredSize(dim);
    text3.setSelectionStart(5);
    text3.setSelectionEnd(20);

    box.add(text1);
    box.add(text2);
    box.add(text3);

    add(box, BorderLayout.CENTER);

  }


  public static void main(String [] args)
  {
    TextFieldDemo app = new TextFieldDemo();

    JFrame f = new JFrame("Text Field Demo");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    ((Window) e.getSource()).dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }
}
