import java.awt.*;
import java.awt.event.*;
import java.util.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.tree.*;

/**
   This class demonstrates use of Swing trees.  Trees consist of tree
   nodes.  You can use the default tree node implementation,
   DefaultMutableTreeNode, to construct elements for your trees.
*/
class TreeEventDemo extends JPanel
{
  /**
     No-arg constructor.  Creates the whole tree object.  
  */
  public TreeEventDemo()
  {
    // Create a set of tree nodes.  Tree nodes can contain other tree
    // nodes.  This is how you build a tree; a node can be a subtree
    // of other nodes.
    //
    DefaultMutableTreeNode travelPlaces = new 
      DefaultMutableTreeNode("Favorite Places to Travel");

    DefaultMutableTreeNode france = new 
      DefaultMutableTreeNode("France");

    DefaultMutableTreeNode paris = new 
      DefaultMutableTreeNode("Paris");

    DefaultMutableTreeNode lyon = new 
      DefaultMutableTreeNode("Lyon");

    DefaultMutableTreeNode stMalo = new 
      DefaultMutableTreeNode("St. Malo");

    // The tree node "france" is a subtree which contains the other
    // tree nodes "paris", "lyon" and "stMalo".
    //
    france.add(paris);
    france.add(lyon);
    france.add(stMalo);

    travelPlaces.add(france);

    // Create a tree node that will be another subtree.  Add other
    // nodes to this one.
    //
    DefaultMutableTreeNode indianOcean = new 
      DefaultMutableTreeNode("Indian Ocean Islands");

    DefaultMutableTreeNode maldives = new 
      DefaultMutableTreeNode("Maldives");

    DefaultMutableTreeNode mauritius = new 
      DefaultMutableTreeNode("Mauritius");

    DefaultMutableTreeNode seychelles = new 
      DefaultMutableTreeNode("Seychelles");

    // Add the other nodes to the "indianOcean" node.
    //
    indianOcean.add(maldives);
    indianOcean.add(mauritius);
    indianOcean.add(seychelles);

    travelPlaces.add(indianOcean);

    // Another subtree.
    //
    DefaultMutableTreeNode us = new 
      DefaultMutableTreeNode("United States");

    DefaultMutableTreeNode la = new 
      DefaultMutableTreeNode("Los Angeles");

    DefaultMutableTreeNode nb = new 
      DefaultMutableTreeNode("Newport Beach");

    DefaultMutableTreeNode sd = new 
      DefaultMutableTreeNode("San Diego");

    DefaultMutableTreeNode boston = new 
      DefaultMutableTreeNode("Pt. Arina");

    // Construct the subtree.
    //
    us.add(la);
    us.add(nb);
    us.add(sd);
    us.add(boston);

    // One more subtree.  Construct it and its child nodes.
    //
    DefaultMutableTreeNode parks = new 
      DefaultMutableTreeNode("National Parks");

    DefaultMutableTreeNode yosemite = new 
      DefaultMutableTreeNode("Yosemite");

    DefaultMutableTreeNode yellowstone = new 
      DefaultMutableTreeNode("Yellowstone");

    DefaultMutableTreeNode shasta = new 
      DefaultMutableTreeNode("Mt. Shasta");

    // Add the children to the root of the subtree.
    //
    parks.add(yosemite);
    parks.add(yellowstone);
    parks.add(shasta);

    us.add(parks);
    travelPlaces.add(us);

    // Event handling stuff.  Don't worry about it now.
    //
    TreeExpansionEventMonitor expansionMonitor = new
      TreeExpansionEventMonitor();

    // Add the nodes to the tree.  The "travelPlaces" node is the
    // root of all other nodes in the tree.
    //
    JTree tree = new JTree(travelPlaces);
    tree.addTreeExpansionListener(expansionMonitor);

    // Configure the tree.
    tree.setPreferredSize(new Dimension(250, 400));
    tree.setFont(new Font("SansSerif", Font.PLAIN, 16));
    JScrollPane treePane = new JScrollPane(tree);
    treePane.setHorizontalScrollBarPolicy(
        JScrollPane.HORIZONTAL_SCROLLBAR_ALWAYS);
    treePane.setVerticalScrollBarPolicy(
        JScrollPane.VERTICAL_SCROLLBAR_ALWAYS);
    treePane.setPreferredSize(new Dimension(250, 400));

    add(treePane);
  }


  public static void main(String [] args)
  {
    TreeEventDemo app = new TreeEventDemo();

    JFrame f = new JFrame("Tree Event Demo");
    WindowListener wL = new WindowAdapter()
      {
	public void windowClosing(WindowEvent e)
	  {
	    e.getWindow().dispose();
	    System.exit(0);
	  }
      };
    f.addWindowListener(wL);

    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }
}


class TreeExpansionEventMonitor implements TreeExpansionListener
{
  public void treeCollapsed(TreeExpansionEvent e)
  {
    System.out.println("Tree collapsed.");
  }

  public void treeExpanded(TreeExpansionEvent e)
  {
    TreePath path = e.getPath();

    System.out.println("Number of path elements = " + path.getPathCount());
  }
}

