import java.awt.*;
import javax.swing.*;

class ActionDemo extends JPanel
{
  public ActionDemo()
  {
    // Create an instance of our action.  
    //
    Action concreteAction = new ConcreteAction();

    // Create an internal frame to place in our main panel.
    //
    JInternalFrame intFrame = new 
      JInternalFrame("Frame with Action Event Sources", 
		     true);
    intFrame.setPreferredSize(new Dimension(450, 200));
    intFrame.getContentPane().setLayout(new BorderLayout());

    // Create a menu bar and add some menus to it.
    // 
    JMenuBar menuBar = new JMenuBar();

    JMenu menu1 = new JMenu("Menu 1");
    JMenu menu2 = new JMenu("Menu 2");
    JMenu menu3 = new JMenu("Menu 3");

    menuBar.add(menu1);
    menuBar.add(menu2);
    menuBar.add(menu3);

    // Add an action to "Menu 2".  This form of "add" creates a
    // menu item and adds it to the menu.  It also registers the
    // action object as an action listener on the menu item.
    //
    JMenuItem menuItem = menu2.add(concreteAction);

    // However, we must set the tool tip text ourselves....
    //
    menuItem.setToolTipText((String) 
			    concreteAction.getValue(Action.LONG_DESCRIPTION));

    // Create another action.  The "action" that this object does is to
    // exit the application when any of its event sources fire the
    // action event.
    //
    Action exit = new ExitAction();
    menu1.add(exit);


    // Add the tool bar to the JInternalFrame.
    //
    intFrame.setJMenuBar(menuBar);

    // Create the button that will be added to our application.
    //
    JButton doIt = new JButton("Do It");

    // Use the action object's long description as our tool tip text.
    //
    String toolTipText = (String) 
      concreteAction.getValue(Action.LONG_DESCRIPTION);
    doIt.setToolTipText(toolTipText);

    // Use the action object's icon for this button's icon.
    //
    Icon icon = (Icon) concreteAction.getValue(Action.SMALL_ICON);
    doIt.setIcon(icon);


    // Add our action object as an action listener on our 
    // stand-alone button.  Notice that this button is the second
    // event source to which we add the same action object.
    //
    doIt.addActionListener(concreteAction);

    // Add our stand-alone button to the internal frame.  
    //
    JPanel buttonPanel = new JPanel();
    buttonPanel.add(doIt);
    
    intFrame.getContentPane().add(buttonPanel, BorderLayout.NORTH);

    add(intFrame, BorderLayout.NORTH);

  }

  public Dimension getPreferredSize()
  {
    return new Dimension(520, 250);
  }


  public static void main(String [] args)
  {
    ActionDemo app = new ActionDemo();

    JFrame f = new JFrame("Action Demo");
    f.getContentPane().add(app);
    f.pack();
    f.setVisible(true);
  }

}
